package com.landray.kmss.sys.attachment.util;

import java.util.ArrayList;
import java.io.File;
import com.landray.kmss.sys.config.loader.ConfigLocationsUtil;
import java.util.Iterator;
import java.util.HashMap;
import java.util.Collection;
import org.apache.commons.collections.CollectionUtils;
import java.util.Map;
import java.util.Collections;
import java.util.Comparator;
import java.util.Arrays;
import com.landray.kmss.framework.service.plugin.Plugin;
import com.landray.kmss.util.StringUtil;
import com.landray.kmss.framework.plugin.core.config.IExtension;
import java.util.List;
import javax.servlet.http.HttpServletRequest;
import org.slf4j.LoggerFactory;
import org.slf4j.Logger;

public class PluginUtil
{
    private final Logger logger;
    private static final String EXTENSION_POINT = "com.landray.kmss.sys.attachment.jg.online";
    private static final String VIEW_ITEM = "view";
    private static final String EDIT_ITEM = "edit";
    private static final String PARAM_JSP = "jsp";
    private static final String PARAM_SCRIPT = "script";
    private static final String PARAM_ORDER = "order";
    private static PluginUtil INSTANCE;
    
    static {
        PluginUtil.INSTANCE = new PluginUtil();
    }
    
    public PluginUtil() {
        this.logger = LoggerFactory.getLogger(this.getClass());
    }
    
    public static PluginUtil getInstance() {
        return PluginUtil.INSTANCE;
    }
    
    public void setEditOnline(final HttpServletRequest request) {
        final String model = (String)request.getAttribute("fdModelName");
        request.setAttribute("editOnlineMap", (Object)this.getEditOnline(model));
    }
    
    public void setViewOnline(final HttpServletRequest request) {
        final String model = (String)request.getAttribute("fdModelName");
        request.setAttribute("viewOnlineMap", (Object)this.getViewOnline(model));
    }
    
    private List<IExtension> getExtension(final String model, final String item) {
        if (StringUtil.isNull(model)) {
            return null;
        }
        final IExtension[] extensions = Plugin.getExtensions("com.landray.kmss.sys.attachment.jg.online", model, item);
        if (extensions == null) {
            return null;
        }
        final List<IExtension> tempExtensions = Arrays.asList(extensions);
        Collections.sort(tempExtensions, new Comparator<IExtension>() {
            @Override
            public int compare(final IExtension o1, final IExtension o2) {
                final Object obj1 = Plugin.getParamValue(o1, "order");
                final Object obj2 = Plugin.getParamValue(o2, "order");
                int order1;
                int order2;
                if (obj1 instanceof Integer) {
                    order1 = (int)obj1;
                    order2 = (int)obj2;
                }
                else {
                    order1 = Integer.valueOf((String)obj1);
                    order2 = Integer.valueOf((String)obj2);
                }
                return order1 - order2;
            }
        });
        return tempExtensions;
    }
    
    private Map<String, List<String>> getEditOnline(final String model) {
        final List<IExtension> extensions = this.getExtension(model, "edit");
        if (CollectionUtils.isNotEmpty((Collection)extensions)) {
            return this.build(extensions);
        }
        return Collections.EMPTY_MAP;
    }
    
    private Map<String, List<String>> getViewOnline(final String model) {
        final List<IExtension> extensions = this.getExtension(model, "view");
        if (CollectionUtils.isNotEmpty((Collection)extensions)) {
            return this.build(extensions);
        }
        return Collections.EMPTY_MAP;
    }
    
    private Map<String, List<String>> build(final List<IExtension> extensions) {
        final Map<String, List<String>> map = new HashMap<String, List<String>>();
        if (extensions != null && !extensions.isEmpty()) {
            for (final IExtension extension : extensions) {
                this.addFile(map, extension, "jsp");
                this.addFile(map, extension, "script");
            }
        }
        return map;
    }
    
    private void addFile(final Map<String, List<String>> map, final IExtension extension, final String param) {
        final String webContentPath = ConfigLocationsUtil.getWebContentPath();
        final String path = Plugin.getParamValueString(extension, param);
        if (StringUtil.isNull(path)) {
            return;
        }
        final File file = new File(String.valueOf(webContentPath) + path);
        if (file.exists()) {
            if (map.get(param) != null && !map.get(param).isEmpty()) {
                final List<String> jspList = map.get(param);
                jspList.add(path);
            }
            else {
                final List<String> jspList = new ArrayList<String>();
                jspList.add(path);
                map.put(param, jspList);
            }
        }
        else {
            this.logger.error("扩展文件：'" + webContentPath + path + "'不存在，请检查文件，当前忽略该配置项");
        }
    }
}
